/***************************************************************************
 *   Copyright (C) 2010 by Vladimir Jary                                   *
 *   <Vladimir.Jary@cern.ch>                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef SPEEXPORTER_H
#define SPEEXPORTER_H


#include<QtCore/QString>

class QFile;
class QDataStream;
class QTextStream;

enum Platform { UNIX, DOS, MAC } ;

class SpeExporter
{
public:
    SpeExporter(QString input);
    ~SpeExporter();
    void export2txt();
    void export2csv();
    void export2pgm();
    void export2asc();
    void export2root();
    inline quint16 getX();
    inline quint16 getY();
    inline quint16 getNumberOfFrames();
    void printHeader();
    void setNewLine(Platform platform);
private:
    qint32 **Allocate2DArray(quint32 rows, quint32 cols);
    void Free2DArray(qint32** buff);
    quint16 readUInt16(QDataStream* instream);
    qint32 readInt32(QDataStream* instream);
    quint16 x, y; //dimension
    quint32 size;
    quint16 frames; //number of frames
    quint16 format; //image format
    void loadData(qint32** buff, QDataStream *in);
    void deleteFile(QFile* file);
    void parseHeader();//get X and Y
    void constructOutputName(QString extension);
    void openStreams();
    void closeStreams();
    //output stream
    QFile *outFile;
    QTextStream *out;
    QString outputName;
    QString newLine;
    //input stream
    QFile *inFile;
    QDataStream *in;
    QString inputName;
    char separator;
};

#endif // SPEEXPORTER_H
